# Xi-CAM XPCS

Xi-CAM GUI plugin that facilitates data exploration and visualization for XPCS experiments.


## Installation

If not already installed, install the main Xi-CAM package: [Xi-CAM](https://github.com/xi-cam/xi-cam)

The latest build of Xi-cam.XPCS is available on pypi
```
pip install xicam.XPCS
```

## Resources

For more information about Xi-CAM, see the [main Xi-CAM repository](https://github.com/xi-cam/xi-cam)
